@@ -1,4 +1,5 @@
 import asyncio
+import logging
 import struct
 from typing import Callable
 
@@ -6,6 +7,8 @@ from ..const import CODE, MESSAGE, ScreenLogicError
 from .protocol import ScreenLogicProtocol
 from .utility import encodeMessageString, decodeMessageString
 
+_LOGGER = logging.getLogger(__name__)
+
 
 def create_login_message():
     # these constants are only for this message.
@@ -19,6 +22,15 @@ def create_login_message():
     return struct.pack(fmt, schema, connectionType, clientVersion, passwd, pid)
 
 
+async def async_get_mac_address(gateway_ip, gateway_port):
+    """Connect to a screenlogic gateway and return the mac address only."""
+    transport, protocol = await async_create_connection(gateway_ip, gateway_port)
+    mac = await async_gateway_connect(transport, protocol)
+    if transport and not transport.is_closing():
+        transport.close()
+    return mac
+
+
 async def async_create_connection(
     gateway_ip, gateway_port, connection_lost_callback: Callable = None
 ):
@@ -26,7 +38,7 @@ async def async_create_connection(
         loop = asyncio.get_running_loop()
 
         # on_con_lost = loop.create_future()
-
+        _LOGGER.debug("Creating connection")
         transport, protocol = await asyncio.wait_for(
             loop.create_connection(
                 lambda: ScreenLogicProtocol(loop, connection_lost_callback),
@@ -36,10 +48,10 @@ async def async_create_connection(
             MESSAGE.COM_TIMEOUT,
         )
         return transport, protocol
-    except asyncio.TimeoutError:
+    except (OSError, asyncio.TimeoutError) as ex:
         raise ScreenLogicError(
             f"Failed to connect to host at {gateway_ip}:{gateway_port}"
-        )
+        ) from ex
 
 
 async def async_gateway_connect(
@@ -48,6 +60,7 @@ async def async_gateway_connect(
     connectString = b"CONNECTSERVERHOST\r\n\r\n"  # as bytes, not string
     try:
         # Connect ping
+        _LOGGER.debug("Pinging protocol adapter")
         transport.write(connectString)
     except Exception as ex:
         raise ScreenLogicError("Error sending connect ping") from ex
@@ -55,8 +68,9 @@ async def async_gateway_connect(
     await asyncio.sleep(0.25)
 
     try:
+        _LOGGER.debug("Sending challenge")
         await asyncio.wait_for(
-            (request := protocol.await_send_data(CODE.CHALLENGE_QUERY)),
+            (request := protocol.await_send_message(CODE.CHALLENGE_QUERY)),
             MESSAGE.COM_TIMEOUT,
         )
         if not request.cancelled():
@@ -68,9 +82,10 @@ async def async_gateway_connect(
 
 async def async_gateway_login(protocol: ScreenLogicProtocol) -> bool:
     try:
+        _LOGGER.debug("Logging in")
         await asyncio.wait_for(
             (
-                request := protocol.await_send_data(
+                request := protocol.await_send_message(
                     CODE.LOCALLOGIN_QUERY, create_login_message()
                 )
             ),
